@@ -30,22 +30,26 @@ app = typer.Typer(
 console = Console()
 
 
+def version_callback(value: bool):
+    """Prints the version of the package."""
+    if value:
+        console.print(
+            f"[yellow]test[/] version: [bold blue]{__version__}[/]"
+        )
+        raise typer.Exit()
+
+
 @app.callback()
 def version(
     version: bool = typer.Option(
         None,
         "-v",
         "--version",
-        # callback=version_callback,
+        callback=version_callback,
         # is_eager=True,
-        help="Prints the version of the zettelkasten package.",
     ),
 ):
-    """ Prints the version of the package"""
-    console.print(
-        f"[yellow]zettelkasten[/] version: [bold blue]{__version__}[/]"
-    )
-    raise typer.Exit()
+    """ Print the version of the package"""
 
 
 @app.command()
